#!/bin/bash
# packager         : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location  : http://prdownloads.sourceforge.net/bashburn/
# last revised     : 19.11.2007

softname='bashburn'
softversion='2.1.2'
packageversion='50.1'
arch='noarch'

# parameters needed for the packaging
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the packaging result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/lib/$softname
mkdir -p $dest/etc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
bashburn: Powerfull Command Line Burning tool
bashburn: 
bashburn: BashBurn can burn data, music and multisession CDs/DVDs.
bashburn: It can burn and create ISO files. It can burn bin/cue files,
bashburn: create mp3s, oggs and flac files. Maybe even more :-)
bashburn: In short, it can do most things you need, and if it can't
bashburn: you're probably doing it wrong.
bashburn: 
bashburn: 
bashburn:
$softname: 
EOF

# extract the source code
cd $buildir
tar zxvf BashBurn-$softversion.tar.gz
cd BashBurn-$softversion

sed -i 's@local/BashBurn@lib/bashburn@g' bashburnrc

# move all stuffs to the right place
cp -Rfp \
      burning config convert func lang menus misc BashBurn.sh \
      $dest/usr/lib/$softname

cp -a \
      ChangeLog COPYING CREDITS INSTALL FAQ README HOWTO TODO \
      $dest/usr/doc/$softname-$softversion
      
cp -a bashburnrc $dest/etc/bashburnrc.new

# /usr/bin
cat << "EOF" > $dest/usr/bin/bashburn
#!/bin/bash
# BashBurn Launcher
/usr/lib/bashburn/BashBurn.sh
EOF
chmod +x $dest/usr/bin/bashburn

# Postinstall file
cat << "EOD" > $dest/install/doinst.sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/bashburnrc.new
EOD

# put the ZenBuild in the right directory
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
